#ifndef VERSION_H
#define VERSION_H

#define FALF_NAM "FALF Player"
#define FALF_VER "1.2 Winkle"

#endif
